import { Logger, Module } from '@nestjs/common'
import { ConfigModule } from '@nestjs/config'
import { nestConfig, securityConfig } from 'src/common/configs'
import { PrismaModule, loggingMiddleware } from 'nestjs-prisma'
import { UsersModule } from './users/users.module'
import { AuthModule } from './auth/auth.module'

@Module({
  imports: [
    ConfigModule.forRoot({
      isGlobal: true,
      load: [nestConfig, securityConfig],
    }),
    PrismaModule.forRoot({
      isGlobal: true,
      prismaServiceOptions: {
        middlewares: [
          loggingMiddleware({
            logger: new Logger('PrismaMiddleware'),
            logLevel: 'log',
          }),
        ],
      },
    }),

    UsersModule,
    AuthModule,
  ],
  controllers: [],
})
export class AppModule {}
